@@ -42,6 +42,7 @@ from dodal.devices.fast_grid_scan import FastGridScanCommon
 from dodal.devices.flux import Flux
 from dodal.devices.i03 import Beamstop, BeamstopPositions
 from dodal.devices.i03.dcm import DCM
+from dodal.devices.i04.transfocator import Transfocator
 from dodal.devices.oav.oav_detector import OAV, OAVConfigBeamCentre
 from dodal.devices.oav.oav_parameters import OAVParameters
 from dodal.devices.oav.pin_image_recognition import PinTipDetection
@@ -68,6 +69,8 @@ from ophyd_async.core import (
     AsyncStatus,
     Device,
     DeviceVector,
+    completed_status,
+    init_devices,
 )
 from ophyd_async.epics.core import epics_signal_rw
 from ophyd_async.epics.motor import Motor
@@ -483,7 +486,10 @@ def baton_in_commissioning_mode(RE: RunEngine, baton: Baton):
 
 @pytest.fixture
 def fast_grid_scan(RE: RunEngine):
-    return i03.zebra_fast_grid_scan(connect_immediately=True, mock=True)
+    scan = i03.zebra_fast_grid_scan(connect_immediately=True, mock=True)
+    for signal in [scan.x_scan_valid, scan.y_scan_valid, scan.z_scan_valid]:
+        set_mock_value(signal, 1)
+    return scan
 
 
 @pytest.fixture
@@ -552,6 +558,14 @@ def ophyd_pin_tip_detection(RE: RunEngine):
     return i03.pin_tip_detection(connect_immediately=True, mock=True)
 
 
+@pytest.fixture()
+def transfocator(RE: RunEngine):
+    with init_devices(mock=True):
+        transfocator = Transfocator("", "")
+    transfocator.set = MagicMock(side_effect=lambda _: completed_status())
+    return transfocator
+
+
 @pytest.fixture
 def robot(done_status, RE: RunEngine):
     robot = i03.robot(connect_immediately=True, mock=True)
@@ -939,7 +953,10 @@ def mock_gridscan_kickoff_complete(gridscan: FastGridScanCommon):
 
 @pytest.fixture
 def panda_fast_grid_scan(RE: RunEngine):
-    return i03.panda_fast_grid_scan(connect_immediately=True, mock=True)
+    scan = i03.panda_fast_grid_scan(connect_immediately=True, mock=True)
+    for signal in [scan.x_scan_valid, scan.y_scan_valid, scan.z_scan_valid]:
+        set_mock_value(signal, 1)
+    return scan
 
 
 @pytest.fixture
@@ -957,6 +974,8 @@ async def hyperion_flyscan_xrc_composite(
     panda,
     backlight,
     s4_slit_gaps,
+    fast_grid_scan,
+    panda_fast_grid_scan,
 ) -> HyperionFlyScanXRayCentreComposite:
     fake_composite = HyperionFlyScanXRayCentreComposite(
         aperture_scatterguard=aperture_scatterguard,
@@ -965,9 +984,7 @@ async def hyperion_flyscan_xrc_composite(
         dcm=dcm,
         # We don't use the eiger fixture here because .unstage() is used in some tests
         eiger=i03.eiger(connect_immediately=True, mock=True),
-        zebra_fast_grid_scan=i03.zebra_fast_grid_scan(
-            connect_immediately=True, mock=True
-        ),
+        zebra_fast_grid_scan=fast_grid_scan,
         flux=i03.flux(connect_immediately=True, mock=True),
         s4_slit_gaps=s4_slit_gaps,
         smargon=smargon,
@@ -977,9 +994,7 @@ async def hyperion_flyscan_xrc_composite(
         zebra=i03.zebra(connect_immediately=True, mock=True),
         zocalo=zocalo,
         panda=panda,
-        panda_fast_grid_scan=i03.panda_fast_grid_scan(
-            connect_immediately=True, mock=True
-        ),
+        panda_fast_grid_scan=panda_fast_grid_scan,
         robot=i03.robot(connect_immediately=True, mock=True),
         sample_shutter=i03.sample_shutter(connect_immediately=True, mock=True),
     )
@@ -1007,8 +1022,6 @@ async def hyperion_flyscan_xrc_composite(
         side_effect=partial(mock_complete, test_result)
     )  # type: ignore
     fake_composite.zocalo.timeout_s = 3
-    set_mock_value(fake_composite.zebra_fast_grid_scan.scan_invalid, False)
-    set_mock_value(fake_composite.zebra_fast_grid_scan.position_counter, 0)
     set_mock_value(fake_composite.smargon.x.max_velocity, 10)
 
     set_mock_value(fake_composite.robot.barcode, "BARCODE")
